@@ -1,5 +1,7 @@
 """
-Main interface for ram service client
+Type annotations for ram service client.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html)
 
 Usage::
 
@@ -15,6 +17,12 @@ from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
+from mypy_boto3_ram.literals import (
+    ResourceOwner,
+    ResourceShareAssociationStatus,
+    ResourceShareAssociationType,
+    ResourceShareStatus,
+)
 from mypy_boto3_ram.paginator import (
     GetResourcePoliciesPaginator,
     GetResourceShareAssociationsPaginator,
@@ -94,7 +102,8 @@ class Exceptions:
 
 class RAMClient:
     """
-    [RAM.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html)
     """
 
     meta: ClientMeta
@@ -104,7 +113,8 @@ class RAMClient:
         self, resourceShareInvitationArn: str, clientToken: str = None
     ) -> AcceptResourceShareInvitationResponseTypeDef:
         """
-        [Client.accept_resource_share_invitation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.accept_resource_share_invitation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.accept_resource_share_invitation)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#accept-resource-share-invitation)
         """
 
     def associate_resource_share(
@@ -115,7 +125,8 @@ class RAMClient:
         clientToken: str = None,
     ) -> AssociateResourceShareResponseTypeDef:
         """
-        [Client.associate_resource_share documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.associate_resource_share)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.associate_resource_share)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#associate-resource-share)
         """
 
     def associate_resource_share_permission(
@@ -126,12 +137,14 @@ class RAMClient:
         clientToken: str = None,
     ) -> AssociateResourceSharePermissionResponseTypeDef:
         """
-        [Client.associate_resource_share_permission documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.associate_resource_share_permission)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.associate_resource_share_permission)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#associate-resource-share-permission)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#can-paginate)
         """
 
     def create_resource_share(
@@ -145,14 +158,16 @@ class RAMClient:
         permissionArns: List[str] = None,
     ) -> CreateResourceShareResponseTypeDef:
         """
-        [Client.create_resource_share documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.create_resource_share)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.create_resource_share)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#create-resource-share)
         """
 
     def delete_resource_share(
         self, resourceShareArn: str, clientToken: str = None
     ) -> DeleteResourceShareResponseTypeDef:
         """
-        [Client.delete_resource_share documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.delete_resource_share)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.delete_resource_share)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#delete-resource-share)
         """
 
     def disassociate_resource_share(
@@ -163,21 +178,24 @@ class RAMClient:
         clientToken: str = None,
     ) -> DisassociateResourceShareResponseTypeDef:
         """
-        [Client.disassociate_resource_share documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.disassociate_resource_share)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.disassociate_resource_share)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#disassociate-resource-share)
         """
 
     def disassociate_resource_share_permission(
         self, resourceShareArn: str, permissionArn: str, clientToken: str = None
     ) -> DisassociateResourceSharePermissionResponseTypeDef:
         """
-        [Client.disassociate_resource_share_permission documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.disassociate_resource_share_permission)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.disassociate_resource_share_permission)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#disassociate-resource-share-permission)
         """
 
     def enable_sharing_with_aws_organization(
         self,
     ) -> EnableSharingWithAwsOrganizationResponseTypeDef:
         """
-        [Client.enable_sharing_with_aws_organization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.enable_sharing_with_aws_organization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.enable_sharing_with_aws_organization)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#enable-sharing-with-aws-organization)
         """
 
     def generate_presigned_url(
@@ -188,14 +206,16 @@ class RAMClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#generate-presigned-url)
         """
 
     def get_permission(
         self, permissionArn: str, permissionVersion: int = None
     ) -> GetPermissionResponseTypeDef:
         """
-        [Client.get_permission documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.get_permission)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.get_permission)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#get-permission)
         """
 
     def get_resource_policies(
@@ -206,23 +226,23 @@ class RAMClient:
         maxResults: int = None,
     ) -> GetResourcePoliciesResponseTypeDef:
         """
-        [Client.get_resource_policies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.get_resource_policies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.get_resource_policies)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#get-resource-policies)
         """
 
     def get_resource_share_associations(
         self,
-        associationType: Literal["PRINCIPAL", "RESOURCE"],
+        associationType: ResourceShareAssociationType,
         resourceShareArns: List[str] = None,
         resourceArn: str = None,
         principal: str = None,
-        associationStatus: Literal[
-            "ASSOCIATING", "ASSOCIATED", "FAILED", "DISASSOCIATING", "DISASSOCIATED"
-        ] = None,
+        associationStatus: ResourceShareAssociationStatus = None,
         nextToken: str = None,
         maxResults: int = None,
     ) -> GetResourceShareAssociationsResponseTypeDef:
         """
-        [Client.get_resource_share_associations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.get_resource_share_associations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.get_resource_share_associations)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#get-resource-share-associations)
         """
 
     def get_resource_share_invitations(
@@ -233,40 +253,44 @@ class RAMClient:
         maxResults: int = None,
     ) -> GetResourceShareInvitationsResponseTypeDef:
         """
-        [Client.get_resource_share_invitations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.get_resource_share_invitations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.get_resource_share_invitations)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#get-resource-share-invitations)
         """
 
     def get_resource_shares(
         self,
-        resourceOwner: Literal["SELF", "OTHER-ACCOUNTS"],
+        resourceOwner: ResourceOwner,
         resourceShareArns: List[str] = None,
-        resourceShareStatus: Literal["PENDING", "ACTIVE", "FAILED", "DELETING", "DELETED"] = None,
+        resourceShareStatus: ResourceShareStatus = None,
         name: str = None,
         tagFilters: List[TagFilterTypeDef] = None,
         nextToken: str = None,
         maxResults: int = None,
     ) -> GetResourceSharesResponseTypeDef:
         """
-        [Client.get_resource_shares documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.get_resource_shares)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.get_resource_shares)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#get-resource-shares)
         """
 
     def list_pending_invitation_resources(
         self, resourceShareInvitationArn: str, nextToken: str = None, maxResults: int = None
     ) -> ListPendingInvitationResourcesResponseTypeDef:
         """
-        [Client.list_pending_invitation_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.list_pending_invitation_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.list_pending_invitation_resources)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list-pending-invitation-resources)
         """
 
     def list_permissions(
         self, resourceType: str = None, nextToken: str = None, maxResults: int = None
     ) -> ListPermissionsResponseTypeDef:
         """
-        [Client.list_permissions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.list_permissions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.list_permissions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list-permissions)
         """
 
     def list_principals(
         self,
-        resourceOwner: Literal["SELF", "OTHER-ACCOUNTS"],
+        resourceOwner: ResourceOwner,
         resourceArn: str = None,
         principals: List[str] = None,
         resourceType: str = None,
@@ -275,26 +299,29 @@ class RAMClient:
         maxResults: int = None,
     ) -> ListPrincipalsResponseTypeDef:
         """
-        [Client.list_principals documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.list_principals)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.list_principals)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list-principals)
         """
 
     def list_resource_share_permissions(
         self, resourceShareArn: str, nextToken: str = None, maxResults: int = None
     ) -> ListResourceSharePermissionsResponseTypeDef:
         """
-        [Client.list_resource_share_permissions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.list_resource_share_permissions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.list_resource_share_permissions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list-resource-share-permissions)
         """
 
     def list_resource_types(
         self, nextToken: str = None, maxResults: int = None
     ) -> ListResourceTypesResponseTypeDef:
         """
-        [Client.list_resource_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.list_resource_types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.list_resource_types)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list-resource-types)
         """
 
     def list_resources(
         self,
-        resourceOwner: Literal["SELF", "OTHER-ACCOUNTS"],
+        resourceOwner: ResourceOwner,
         principal: str = None,
         resourceType: str = None,
         resourceArns: List[str] = None,
@@ -303,31 +330,36 @@ class RAMClient:
         maxResults: int = None,
     ) -> ListResourcesResponseTypeDef:
         """
-        [Client.list_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.list_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.list_resources)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list-resources)
         """
 
     def promote_resource_share_created_from_policy(
         self, resourceShareArn: str
     ) -> PromoteResourceShareCreatedFromPolicyResponseTypeDef:
         """
-        [Client.promote_resource_share_created_from_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.promote_resource_share_created_from_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.promote_resource_share_created_from_policy)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#promote-resource-share-created-from-policy)
         """
 
     def reject_resource_share_invitation(
         self, resourceShareInvitationArn: str, clientToken: str = None
     ) -> RejectResourceShareInvitationResponseTypeDef:
         """
-        [Client.reject_resource_share_invitation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.reject_resource_share_invitation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.reject_resource_share_invitation)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#reject-resource-share-invitation)
         """
 
     def tag_resource(self, resourceShareArn: str, tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.tag_resource)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#tag-resource)
         """
 
     def untag_resource(self, resourceShareArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.untag_resource)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#untag-resource)
         """
 
     def update_resource_share(
@@ -338,7 +370,8 @@ class RAMClient:
         clientToken: str = None,
     ) -> UpdateResourceShareResponseTypeDef:
         """
-        [Client.update_resource_share documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Client.update_resource_share)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Client.update_resource_share)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#update-resource-share)
         """
 
     @overload
@@ -346,7 +379,7 @@ class RAMClient:
         self, operation_name: Literal["get_resource_policies"]
     ) -> GetResourcePoliciesPaginator:
         """
-        [Paginator.GetResourcePolicies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Paginator.GetResourcePolicies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Paginator.GetResourcePolicies)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourcepoliciespaginator)
         """
 
     @overload
@@ -354,7 +387,7 @@ class RAMClient:
         self, operation_name: Literal["get_resource_share_associations"]
     ) -> GetResourceShareAssociationsPaginator:
         """
-        [Paginator.GetResourceShareAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourceshareassociationspaginator)
         """
 
     @overload
@@ -362,7 +395,7 @@ class RAMClient:
         self, operation_name: Literal["get_resource_share_invitations"]
     ) -> GetResourceShareInvitationsPaginator:
         """
-        [Paginator.GetResourceShareInvitations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourceshareinvitationspaginator)
         """
 
     @overload
@@ -370,17 +403,17 @@ class RAMClient:
         self, operation_name: Literal["get_resource_shares"]
     ) -> GetResourceSharesPaginator:
         """
-        [Paginator.GetResourceShares documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Paginator.GetResourceShares)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Paginator.GetResourceShares)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourcesharespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_principals"]) -> ListPrincipalsPaginator:
         """
-        [Paginator.ListPrincipals documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Paginator.ListPrincipals)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Paginator.ListPrincipals)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#listprincipalspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_resources"]) -> ListResourcesPaginator:
         """
-        [Paginator.ListResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.48/reference/services/ram.html#RAM.Paginator.ListResources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Paginator.ListResources)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#listresourcespaginator)
         """
